import Foundation

public class AutenticacaoService {
    
    private let BASE_API = "http://localhost:8000/api/v1"
    
    public static let shared = AutenticacaoService()
    
    public enum APIErro: Error {
        case error(_ errorString: String)
    }
    
    public func login<T: Decodable>(_ email: String , _ senha: String, completion: @escaping (Result<T,APIErro>) -> Void ) {
        let url = URL(string: "\(BASE_API)/usuario/login")!
        var request = URLRequest(url: url)
        let parametros = [ "email" : email , "senha": senha  ]
        let body = try! JSONSerialization.data(withJSONObject: parametros)
        request.setValue("application/json", forHTTPHeaderField: "Content-Type")
        request.httpMethod = "POST"
        request.httpBody = body
        
        URLSession.shared.dataTask(with: request) { (data,response,error) in
            let httpResponse = response as? HTTPURLResponse
            let statusCode = httpResponse?.statusCode
            
            
            if statusCode! >= 500 {
                completion(.failure(.error("Erro no servidor, tente novamente")))
                return
            }
            
            else if statusCode! == 400 {
                completion(.failure(.error("Email ou Senha inválidos")))
                return
            }
            
            
            do {
                
                guard let data = data else {
                    completion(.failure(.error("Dados corrompidos. Tente novamente")))
                    return
                }
                
                let dados = try JSONDecoder().decode(T.self, from: data)
                completion(.success(dados))
                return
            }
            catch _ {
                completion(.failure(.error("Dados corrompidos. Tente novamente")))
                return
            }
            
        }.resume()
    }
    
    public func registrar<T: Decodable>( _ nome: String, _ email: String , _ senha: String, completion: @escaping (Result<T,APIErro>) -> Void ) {
        let url = URL(string: "\(BASE_API)/usuario")!
        var request = URLRequest(url: url)
        let parametros = [ "nome": nome, "email" : email , "senha": senha  ]
        let body = try! JSONSerialization.data(withJSONObject: parametros)
        request.setValue("application/json", forHTTPHeaderField: "Content-Type")
        request.httpMethod = "POST"
        request.httpBody = body
        
        URLSession.shared.dataTask(with: request) { (data,response,error) in
            let httpResponse = response as? HTTPURLResponse
            let statusCode = httpResponse?.statusCode
            
            
            if statusCode! >= 500 {
                completion(.failure(.error("Erro no servidor, tente novamente")))
                return
            }
            
            else if statusCode! == 401 {
                completion(.failure(.error("Email já cadastrado")))
                return
            }
            
            
            do {
                
                guard let data = data else {
                    completion(.failure(.error("Dados corrompidos. Tente novamente")))
                    return
                }
                
                let dados = try JSONDecoder().decode(T.self, from: data)
                completion(.success(dados))
                return
            }
            catch _ {
                completion(.failure(.error("Dados corrompidos. Tente novamente")))
                return
            }
            
        }.resume()
    }
}
