import Foundation

public class SolicitacaoService {
    private let BASE_API = "http://localhost:8000/api/v1"
    
    public static let shared = SolicitacaoService()
    
    public enum APIErro: Error {
        case error(_ errorString: String)
    }
    
    public func solicitarPresenca<T: Decodable>(jwt:String,evento: Int, completion: @escaping (Result<T,APIErro>) -> Void) {
        let url = URL(string: "\(BASE_API)/solicitacao/\(evento)")!
        var request = URLRequest(url: url)
        request.setValue("application/json", forHTTPHeaderField: "Content-Type")
        request.setValue(jwt, forHTTPHeaderField: "jwt")
        request.httpMethod = "POST"
        
        URLSession.shared.dataTask(with: request) { (data,response,erro) in
            let httpResponse = response as? HTTPURLResponse
            let statusCode = httpResponse?.statusCode
            
            
            if statusCode! >= 500 {
                completion(.failure(.error("Erro no servidor, tente novamente")))
                return
            }
            
            else if statusCode! >= 400 {
                completion(.failure(.error("Não autenticado")))
                return
            }
            
            else if statusCode! >= 201 {
                completion(.failure(.error("Vazio")))
                return
            }
            
            
            do {
                
                guard let data = data else {
                    completion(.failure(.error("Dados corrompidos. Tente novamente")))
                    return
                }
                
                let dados = try JSONDecoder().decode(T.self, from: data)
                completion(.success(dados))
                return
            }
            catch  {
                print(error)
                completion(.failure(.error("Dados corrompidos. Tente novamente")))
                return
            }
            
        }.resume()
        
    }
    
    public func getSolicitacoes<T: Decodable>(jwt:String,evento: Int, completion: @escaping (Result<T,APIErro>) -> Void) {
        let url = URL(string: "\(BASE_API)/solicitacao/\(evento)")!
        var request = URLRequest(url: url)
        request.setValue("application/json", forHTTPHeaderField: "Content-Type")
        request.setValue(jwt, forHTTPHeaderField: "jwt")
        request.httpMethod = "GET"
        
        URLSession.shared.dataTask(with: request) { (data,response,erro) in
            let httpResponse = response as? HTTPURLResponse
            let statusCode = httpResponse?.statusCode
            
            
            if statusCode! >= 500 {
                completion(.failure(.error("Erro no servidor, tente novamente")))
                return
            }
            
            else if statusCode! >= 400 {
                completion(.failure(.error("Não autenticado")))
                return
            }
            
            else if statusCode! >= 201 {
                completion(.failure(.error("Vazio")))
                return
            }
            
            
            do {
                
                guard let data = data else {
                    completion(.failure(.error("Dados corrompidos. Tente novamente")))
                    return
                }
                
                let dados = try JSONDecoder().decode(T.self, from: data)
                completion(.success(dados))
                return
            }
            catch  {
                print(error)
                completion(.failure(.error("Dados corrompidos. Tente novamente")))
                return
            }
            
        }.resume()
        
    }
    
    public func confirmarSolicitacao<T: Decodable>(jwt:String,solicitacao: Int, completion: @escaping (Result<T,APIErro>) -> Void) {
        let url = URL(string: "\(BASE_API)/solicitacao/confirmar/\(solicitacao)")!
        var request = URLRequest(url: url)
        request.setValue("application/json", forHTTPHeaderField: "Content-Type")
        request.setValue(jwt, forHTTPHeaderField: "jwt")
        request.httpMethod = "POST"
        
        URLSession.shared.dataTask(with: request) { (data,response,erro) in
            let httpResponse = response as? HTTPURLResponse
            let statusCode = httpResponse?.statusCode
            
            
            if statusCode! >= 500 {
                completion(.failure(.error("Erro no servidor, tente novamente")))
                return
            }
            
            else if statusCode! >= 400 {
                completion(.failure(.error("Não autenticado")))
                return
            }
            
            else if statusCode! >= 201 {
                completion(.failure(.error("Vazio")))
                return
            }
            
            
            do {
                
                guard let data = data else {
                    completion(.failure(.error("Dados corrompidos. Tente novamente")))
                    return
                }
                
                let dados = try JSONDecoder().decode(T.self, from: data)
                completion(.success(dados))
                return
            }
            catch  {
                print(error)
                completion(.failure(.error("Dados corrompidos. Tente novamente")))
                return
            }
            
        }.resume()
        
    }
    
    public func apagarSolicitacao<T: Decodable>(jwt:String,solicitacao: Int, completion: @escaping (Result<T,APIErro>) -> Void) {
        let url = URL(string: "\(BASE_API)/solicitacao/\(solicitacao)")!
        var request = URLRequest(url: url)
        request.setValue("application/json", forHTTPHeaderField: "Content-Type")
        request.setValue(jwt, forHTTPHeaderField: "jwt")
        request.httpMethod = "DELETE"
        
        URLSession.shared.dataTask(with: request) { (data,response,erro) in
            let httpResponse = response as? HTTPURLResponse
            let statusCode = httpResponse?.statusCode
            
            
            if statusCode! >= 500 {
                completion(.failure(.error("Erro no servidor, tente novamente")))
                return
            }
            
            else if statusCode! >= 400 {
                completion(.failure(.error("Não autenticado")))
                return
            }
            
            
            do {
                
                guard let data = data else {
                    completion(.failure(.error("Dados corrompidos. Tente novamente")))
                    return
                }
                
                let dados = try JSONDecoder().decode(T.self, from: data)
                completion(.success(dados))
                return
            }
            catch  {
                print(error)
                completion(.failure(.error("Dados corrompidos. Tente novamente")))
                return
            }
            
        }.resume()
        
    }
    
    public func removerParticipacao<T: Decodable>(jwt:String,assentoId: Int, completion: @escaping (Result<T,APIErro>) -> Void) {
        let url = URL(string: "\(BASE_API)/solicitacao/assento/\(assentoId)")!
        var request = URLRequest(url: url)
        request.setValue("application/json", forHTTPHeaderField: "Content-Type")
        request.setValue(jwt, forHTTPHeaderField: "jwt")
        request.httpMethod = "DELETE"
        
        URLSession.shared.dataTask(with: request) { (data,response,erro) in
            let httpResponse = response as? HTTPURLResponse
            let statusCode = httpResponse?.statusCode
            
            
            if statusCode! >= 500 {
                completion(.failure(.error("Erro no servidor, tente novamente")))
                return
            }
            
            else if statusCode! >= 400 {
                completion(.failure(.error("Não autenticado")))
                return
            }
            
            
            do {
                
                guard let data = data else {
                    completion(.failure(.error("Dados corrompidos. Tente novamente")))
                    return
                }
                
                let dados = try JSONDecoder().decode(T.self, from: data)
                completion(.success(dados))
                return
            }
            catch  {
                print(error)
                completion(.failure(.error("Dados corrompidos. Tente novamente")))
                return
            }
            
        }.resume()
        
    }
    
}
