import Foundation

struct FormDataRequest {
    private let boundary: String = UUID().uuidString
    private var httpBody = NSMutableData()
    let url: URL
    let jwt: String
    
    init(url: String, jwt: String) {
        self.url = URL(string: url)!
        self.jwt = jwt
    }
    
    func addArrayField(name: String, value: [Int]) {
        for valor in value {
            addTextField(name: name, value: String(valor))
        }
    }
    
    func addTextField(name: String, value: String) {
        httpBody.append(textFormField(name: name, value: value))
    }
    
    private func textFormField(name: String, value: String) -> String {
        var fieldString = "--\(boundary)\r\n"
        fieldString += "Content-Disposition: form-data; name=\"\(name)\"\r\n"
        fieldString += "Content-Type: text/plain; charset=ISO-8859-1\r\n"
        fieldString += "Content-Transfer-Encoding: 8bit\r\n"
        fieldString += "\r\n"
        fieldString += "\(value)\r\n"
        
        return fieldString
    }
    
    func addDataField(name: String,fileName: String, data: Data, mimeType: String) {
        httpBody.append(dataFormField(name: name,fileName: fileName , data: data, mimeType: mimeType))
    }
    
    private func dataFormField(name: String,fileName: String,data: Data, mimeType: String) -> Data {
        let fieldData = NSMutableData()
        fieldData.append("--\(boundary)\r\n")
        fieldData.append("Content-Disposition: form-data; name=\"\(name)\"; filename=\"\(fileName)\"\r\n")
        fieldData.append("Content-Type: \(mimeType)\r\n")
        fieldData.append("\r\n")
        fieldData.append(data)
        fieldData.append("\r\n")
        
        return fieldData as Data
    }
    
    func asURLRequest() -> URLRequest {
        var request = URLRequest(url: url)
        
        request.httpMethod = "POST"
        request.setValue(jwt, forHTTPHeaderField: "jwt")
        request.setValue("multipart/form-data; boundary=\(boundary)", forHTTPHeaderField: "Content-Type")
        
        httpBody.append("--\(boundary)--")
        request.httpBody = httpBody as Data
        return request
    }
}
