import Foundation
import UIKit

class PerfilVM: ObservableObject {
    
    @Published var mostrarMensagemErro = false
    @Published var mensagemErro = ""
    @Published var nome = ""
    @Published var email = ""
    @Published var foto = ""
    
    @Published var imagem: UIImage?
    
    @Published var imagemAtualizada = false
    
    
    func getPerfil(_ jwt: String) {
        let usuarioService = UsuarioService.shared
        usuarioService.getPerfil(jwt) { (result: Result<PerfilResponse,UsuarioService.APIErro>) in
            switch result {
            case .success(let response):
                DispatchQueue.main.async {
                    self.nome = response.nome
                    self.email = response.email
                    self.foto = response.foto
                }
            case .failure(let erro):
                DispatchQueue.main.async {
                    switch erro {
                    case .error(let erroDescricao):
                        self.mostrarMensagemErro = true
                        self.mensagemErro = erroDescricao
                    }
                }
            }
        }
        
    }
    
    func atualizarFoto(_ jwt: String) {
        if imagem == nil {
            return
        }
        let usuarioService = UsuarioService.shared
        usuarioService.alterarFoto(jwt:jwt, imagem: (imagem?.pngData())!) { (result: Result<AlterarFotoResponse,UsuarioService.APIErro>) in
            switch result {
            case .success(_):
                DispatchQueue.main.async {
                    self.imagemAtualizada = true
                }
            case .failure(let erro):
                DispatchQueue.main.async {
                    switch erro {
                    case .error(let erroDescricao):
                        self.imagemAtualizada = false
                        self.mostrarMensagemErro = true
                        self.mensagemErro = erroDescricao
                    }
                }
            }
        }
        
    }
}
