import Foundation

class SolicitacoesVM: ObservableObject {
    
    @Published var mostrarMensagemErro = false
    @Published var mensagemErro = ""
    @Published var opcao : TiposSolicitacoes = .pendentes
    @Published var solicitacoes: [GetSolicitacoesResponse] = []
    
    @Published var participacoesConfirmadas: [AssentosParticipacao] = []
    
    @Published var solicitacaoConfirmada = false
    
    @Published var solicitacaoApagada = false
    
    @Published var participacaoRemovida = false
    
    init() {}
    
    func getSolicitacoes(jwt: String, evento: Int) {
        let solicitacaoService = SolicitacaoService.shared
        solicitacaoService.getSolicitacoes(jwt: jwt,evento:evento ) { (result: Result<[GetSolicitacoesResponse],SolicitacaoService.APIErro>) in
            switch result {
            case .success(let response):
                DispatchQueue.main.async {
                    print(response)
                    self.solicitacoes = response
                }
            case .failure(let erro):
                DispatchQueue.main.async {
                    switch erro {
                    case .error(let erroDescricao):
                        if erroDescricao == "Vazio" {
                            self.solicitacoes = []
                            self.mensagemErro = "Não há mais assentos"
                            self.solicitacaoConfirmada = false
                        } else {
                            self.solicitacaoConfirmada = false
                            self.mostrarMensagemErro = true
                            self.mensagemErro = erroDescricao
                        }
                    }
                }
            }
        }
    }
    
    func confirmarSolicitacao(jwt: String, solicitacao: Int) {
        let solicitacaoService = SolicitacaoService.shared
        solicitacaoService.confirmarSolicitacao(jwt: jwt,solicitacao: solicitacao ) { (result: Result<ConfirmarSolicitacaoResponse,SolicitacaoService.APIErro>) in
            switch result {
            case .success(_):
                DispatchQueue.main.async {
                    self.solicitacaoConfirmada = true
                    
                }
            case .failure(let erro):
                DispatchQueue.main.async {
                    switch erro {
                    case .error(let erroDescricao):
                        if erroDescricao == "Vazio" {
                            self.solicitacoes = []
                            self.mensagemErro = "Não há mais assentos"
                            self.solicitacaoConfirmada = false
                        } else {
                            self.solicitacaoConfirmada = false
                            self.mostrarMensagemErro = true
                            self.mensagemErro = erroDescricao
                        }
                    }
                }
            }
        }
    }
    
    func consultarParticipacoes(jwt: String, eventoId: Int) {
        let eventoService = EventoService.shared
        eventoService.consultarParticipacoes(jwt: jwt,id: eventoId ) { (result: Result<[ParticipacoesConfirmadasResponse],EventoService.APIErro>) in
            switch result {
            case .success(let response):
                DispatchQueue.main.async {
                    self.participacoesConfirmadas = response[0].assentos
                    
                }
            case .failure(let erro):
                DispatchQueue.main.async {
                    switch erro {
                    case .error(let erroDescricao):
                        if erroDescricao == "Vazio" {
                            self.participacoesConfirmadas = []
                        } else {
                            self.mostrarMensagemErro = true
                            self.mensagemErro = erroDescricao
                        }
                    }
                }
            }
        }
    }
    
    
    func apagarSolicitacao(jwt: String, solicitacaoId: Int) {
        let solicitacaoService = SolicitacaoService.shared
        solicitacaoService.apagarSolicitacao(jwt: jwt,solicitacao: solicitacaoId) { (result: Result<ApagarSolicitacaoResponse,SolicitacaoService.APIErro>) in
            switch result {
            case .success(_):
                DispatchQueue.main.async {
                    self.solicitacaoApagada = true
                }
            case .failure(let erro):
                DispatchQueue.main.async {
                    switch erro {
                    case .error(let erroDescricao):
                        self.solicitacaoApagada = false
                        self.mostrarMensagemErro = true
                        self.mensagemErro = erroDescricao
                    }
                }
            }
        }
    }
    
    func removerParticipacao(jwt: String, assentoId: Int) {
        let solicitacaoService = SolicitacaoService.shared
        solicitacaoService.removerParticipacao (jwt: jwt,assentoId: assentoId) { (result: Result<AssentoLiberadoResponse,SolicitacaoService.APIErro>) in
            switch result {
            case .success(_):
                DispatchQueue.main.async {
                    self.participacaoRemovida = true
                }
            case .failure(let erro):
                DispatchQueue.main.async {
                    switch erro {
                    case .error(let erroDescricao):
                        self.participacaoRemovida = false
                        self.mostrarMensagemErro = true
                        self.mensagemErro = erroDescricao
                    }
                }
            }
        }
    }
    
}
