import SwiftUI

struct AdicionarEventoView: View {
    
    @StateObject var addEventoVM = AdicionarEventoVM()
    @State private var showSheet: Bool = false
    @State private var showImagePicker: Bool = false
    @State private var sourceType: UIImagePickerController.SourceType = .photoLibrary
    @Environment(\.presentationMode) var presentationMode
    
    var body: some View {
        
        Form {
            
            Section {
                HStack {
                    Spacer()
                    Image(uiImage: addEventoVM.imagem ?? UIImage(named: "placeholder")!)
                        .resizable()
                        .frame(width: 300, height: 300)
                        .onTapGesture {
                            self.showSheet = true
                        }
                    Spacer()
                }
            } header: {
                Text("Adicione uma imagem para o evento")
            }
            
            
            Section  {
                TextField("Adicione um título:", text: $addEventoVM.titulo)
                
                TextEditor(text: $addEventoVM.descricao)
                    .foregroundColor(addEventoVM.estaDigitando() ? .black : .gray)
                DatePicker("Selecione a Data:", selection: $addEventoVM.data)
                    .datePickerStyle(GraphicalDatePickerStyle())
                    .environment(\.locale, Locale.init(identifier: "pt"))
                
            } header: {
                Text("Informações básicas do evento")
            }
            
            Section {
                TextField("Adicione um link (opcional)", text: $addEventoVM.link)
            } header: {
                Text("Informações adicionais do evento")
            }
            
            Section {
                Stepper("Quantidade de Linhas", value: $addEventoVM.total_assentos_linhas, in: 1...8)
                Stepper("Quantidade de colunas", value: $addEventoVM.total_Assentos_colunas, in: 1...8)
                
                AlocarEspaco(total_assentos_linhas: $addEventoVM.total_assentos_linhas, total_assentos_colunas: $addEventoVM.total_Assentos_colunas, assentosBloqueados: $addEventoVM.assentosBloqueados)
                    .padding()
                
                HStack {
                    
                    Spacer()
                    
                    VStack {
                        Color.green
                            .frame(width: 50, height: 30)
                            .cornerRadius(12)
                        
                        Text("Disponível")
                    }
                    
                    VStack {
                        Color.gray
                            .frame(width: 50, height: 30)
                            .cornerRadius(12)
                            .overlay(Image(systemName: "xmark"))
                        
                        Text("Bloqueado")
                    }
                    
                    Spacer()
                    
                }
                
            } header: {
                Text("Quantidade de assentos e quais desses não devem ser utilizados")
            } footer: {
                Text("A alocação não poderá ser alterada")
            }
            
            
        }
        
        .navigationTitle("Adicionar Evento")
        .navigationBarItems(trailing: Button(action: {
            self.addEventoVM.adicionar()
            presentationMode.wrappedValue.dismiss()
        }, label: {
            Text("Salvar")
        }))
        .alert(isPresented: $addEventoVM.mostrarMensagemErro) {
            Alert(
                title: Text("OOPS"),
                message: Text(addEventoVM.mensagemErro),
                dismissButton: .default(Text("OK"), action: {
                    addEventoVM.mostrarMensagemErro = false
                })
            )
        }
        .actionSheet(isPresented: $showSheet) {
            ActionSheet(title: Text("Selecione uma foto"), message: Text("Escolha da galeria ou tire uma foto"), buttons: [
                .default(Text("Photo Library")) {
                    self.showImagePicker = true
                    self.sourceType = .photoLibrary
                },
                .default(Text("Camera")) {
                    self.showImagePicker = true
                    self.sourceType = .camera
                },
                .cancel()
            ])
        }
        .sheet(isPresented: $showImagePicker) {
            ImagePicker(image: $addEventoVM.imagem, isShown: self.$showImagePicker, sourceType: self.sourceType)
        }
    }
}

struct AdicionarEventoView_Previews: PreviewProvider {
    static var previews: some View {
        AdicionarEventoView()
    }
}
