import SwiftUI

struct EventoDetalheView: View {
    
    @State var evento: EventoResponse?
    @Environment(\.presentationMode) var presentationMode
    @StateObject var eventoDetalheVM = EventoDetalheVM()
    @State var gerenciarEvento = false
    @Binding var atualizar: Bool
    
    @AppStorage("jwt") var jwt = ""
    
    var body: some View {
        ScrollView {
            VStack(alignment: .leading) {
                if #available(iOS 15.0, *) {
                    AsyncImage(url: URL(string: evento?.imagem ?? "")) { imagem in
                        imagem.resizable()
                            .frame(width: .infinity, height: 300)
                    } placeholder: {
                        Image("placeholder")
                            .resizable()
                            .frame(width: .infinity, height: 300)
                    }
                } //Imagem
                
                VStack(alignment: .leading) {
                    HStack {
                        Text(evento?.titulo ?? "")
                            .font(.title)
                            .multilineTextAlignment(.leading)
                        
                        Spacer()
                        
                        Text(evento?.data.toFullFormat(evento?.data ?? "") ?? "")
                            .font(.caption)
                        
                    }
                    .padding(.bottom,10)
                    
                    Text("Descrição:")
                        .foregroundColor(.gray)
                    Text(evento?.descricao ?? "")
                        .multilineTextAlignment(.leading)
                    
                    NavigationLink(isActive: $gerenciarEvento) {
                        SolicitacoesView(eventoId: evento?.id ?? 0)
                    } label: {
                        EmptyView()
                    }
                    
                    
                    VStack {
                        Text("Informações adicionais:")
                            .foregroundColor(.gray)
                            .padding(.top,20)
                            .alert(isPresented: $eventoDetalheVM.solicitacaoEnviada) {
                                Alert(
                                    title: Text("Sucesso"),
                                    message: Text("Solicitacao feita com sucesso"),
                                    dismissButton: .default(Text("OK"), action: {
                                        //
                                    })
                                )
                            }
                        
                        Text(evento?.link ?? "")
                            .multilineTextAlignment(.leading)
                            .alert(isPresented: $eventoDetalheVM.eventoApagado) {
                                Alert(
                                    title: Text("Sucesso"),
                                    message: Text("Evento apagado com sucessso"),
                                    dismissButton: .default(Text("OK"), action: {
                                        self.presentationMode.wrappedValue.dismiss()
                                    })
                                )
                            }
                    }
                    
                    VStack {
                        Text("Código do evento:")
                            .foregroundColor(.gray)
                            .padding(.top,20)
                        
                        Text(evento?.codigo ?? "")
                            .multilineTextAlignment(.leading)
                    }
                    
                    Text("Ocupação:")
                        .foregroundColor(.gray)
                        .padding(.top,10)
                    
                    
                    if evento?.assentos != nil {
                        VistaAssentos(  total_assentos_linhas: evento?.total_assentos_linha ?? 0, total_assentos_colunas: evento?.total_assentos_coluna ?? 0, assentos: evento?.assentos ?? [])
                    }
                    
                    if evento?.permissaoAlterar == false {
                        
                        HStack {
                            Spacer()
                            if #available(iOS 15.0, *) {
                                Button {
                                    eventoDetalheVM.solicitarPresenca(jwt: jwt, id: evento?.id ?? 0)
                                } label: {
                                    Text("Solicitar presença")
                                        .frame(width: 300, height: 30)
                                        .foregroundColor(.white)
                                    
                                    
                                }.buttonStyle(.bordered)
                                    .background(Color.blue)
                                    .padding(.bottom,20)
                            }
                            Spacer()
                        }
                        .padding(.top,20)
                    }
                    
                    if evento?.permissaoAlterar != false {
                        
                        HStack {
                            Spacer()
                            if #available(iOS 15.0, *) {
                                Button {
                                    eventoDetalheVM.apagar(jwt: jwt, id: evento?.id ?? 0)
                                    atualizar = true
                                } label: {
                                    Text("Apagar Evento")
                                        .frame(width: 300, height: 30)
                                        .foregroundColor(.white)
                                    
                                    
                                }.buttonStyle(.bordered)
                                    .background(Color.red)
                                    .padding(.bottom,20)
                            }
                            Spacer()
                        }
                        .padding(.top,20)
                    }
                    
                }
                .padding()
                
                Spacer()
            }
            
        }
        .navigationBarItems(trailing: (evento?.permissaoAlterar != false) ? AnyView(Button {
            self.gerenciarEvento = true
        } label: {
            Text("Gerenciar")
        })  : AnyView(EmptyView()) )
        .edgesIgnoringSafeArea(.top)
        .navigationTitle("Evento")
        .navigationBarTitleDisplayMode(.inline)
        
    }
}

