import SwiftUI

struct LoginView: View {
    @EnvironmentObject var loginVM : LoginVM
    
    var body: some View {
        NavigationView {
            VStack {
                
                Text("EventosApp")
                    .font(.system(size: 50))
                    .padding(.bottom,46)
                
                TextField("Digite seu email", text: $loginVM.email)
                    .autocapitalization(.none)
                    .padding()
                
                SecureField("Digite sua senha", text: $loginVM.senha)
                    .autocapitalization(.none)
                    .padding()
                    .padding(.bottom,30)
                    .autocapitalization(.none)
                
                if #available(iOS 15.0, *) {
                    Button {
                        loginVM.login()
                    } label: {
                        Text("Login")
                            .frame(width: 300, height: 30)
                            .foregroundColor(.white)
                        
                        
                    }.buttonStyle(.bordered)
                        .background(Color.blue)
                        .padding(.bottom,20)
                }
                
                
                
                NavigationLink("Registrar-se", destination: RegistroView())
                
            }
            .padding()
            .alert(isPresented: $loginVM.mostrarMensagemErro) {
                Alert(
                    title: Text("OOPS"),
                    message: Text(loginVM.mensagemErro),
                    dismissButton: .default(Text("OK"), action: {
                        loginVM.mostrarMensagemErro = false
                    })
                )
            }
        }
        
    }
}

struct LoginView_Previews: PreviewProvider {
    static var previews: some View {
        LoginView()
    }
}
