import SwiftUI

struct MeusEventosView: View {
    
    @StateObject var meusEventosVM = MeusEventosVM()
    @AppStorage("jwt") var jwt = ""
    @State var atualizar = false
    
    var body: some View {
        NavigationView {
            ScrollView {
                Picker("Selecione um Tipo", selection: $meusEventosVM.opcao) {
                    ForEach(TiposEventos.allCases,id: \.self) {
                        Text($0.rawValue)
                    }
                }
                .pickerStyle(SegmentedPickerStyle())
                .onChange(of: meusEventosVM.opcao, perform: { newValue in
                    meusEventosVM.getEventos(jwt: jwt)
                })
                .padding()
                
                ForEach(meusEventosVM.eventos , id: \.id) { evento in
                    NavigationLink {
                        EventoDetalheView(evento: evento,atualizar: $atualizar)
                    } label: {
                        MeusEventosItem(evento: evento )
                    }
                }
                .onChange(of: atualizar) { newValue in
                    meusEventosVM.getEventos(jwt: jwt)
                    atualizar = false
                }
                
                if (meusEventosVM.eventos.count == 0) {
                    Text("Não há eventos")
                }
                
                NavigationLink(isActive: $meusEventosVM.achouEvento) {
                    EventoDetalheView(evento: meusEventosVM.evento,atualizar: $atualizar)
                } label: {
                    EmptyView()
                }
                
                
            }
            .navigationTitle("Meus Eventos")
            .alert(isPresented: $meusEventosVM.mostrarMensagemErro) {
                Alert(
                    title: Text("OOPS"),
                    message: Text(meusEventosVM.mensagemErro),
                    dismissButton: .default(Text("OK"), action: {
                        meusEventosVM.mostrarMensagemErro = false
                    })
                )
            }
            .navigationBarItems(
                trailing: HStack {
                    Button {
                        alertView()
                    } label: {
                        Image(systemName: "calendar")
                            .font(.system(size: 20))
                    }
                    
                    NavigationLink(destination: AdicionarEventoView(), label: {
                        Image(systemName: "plus")
                            .font(.system(size: 20))
                    })
                }
            )
            
        } // Navigation view
        .onAppear {
            meusEventosVM.getEventos(jwt: jwt)
        }
    }
    
    func alertView() {
        let alert = UIAlertController(title: "Buscar evento", message: "Insira o código", preferredStyle: .alert)
        
        alert.addTextField { codigo in
            codigo.placeholder = "Código"
        }
        
        let buscarAcao = UIAlertAction(title: "Buscar", style: .default) { (_) in
            meusEventosVM.codigo = alert.textFields?[0].text ?? ""
            meusEventosVM.getEvento(jwt: jwt)
        }
        
        let cancelarAcao = UIAlertAction(title: "Cancelar", style: .destructive) { (_) in
            
        }
        
        alert.addAction(buscarAcao)
        alert.addAction(cancelarAcao)
        
        UIApplication.shared.windows.first?.rootViewController?.present(alert,animated: true,completion: {})
    }
}

struct MeusEventosView_Previews: PreviewProvider {
    static var previews: some View {
        MeusEventosView()
    }
}
