import SwiftUI

struct PerfilView: View {
    
    @StateObject var perfilVM = PerfilVM()
    @AppStorage("jwt") var jwt: String = ""
    @State var mostrarOpcoes = false
    
    @State var alterarDados = false
    @State var alterarSenha = false
    
    @State private var showSheet: Bool = false
    @State private var showImagePicker: Bool = false
    @State private var sourceType: UIImagePickerController.SourceType = .photoLibrary
    
    var body: some View {
        NavigationView {
            VStack(alignment: .leading) {
                
                HStack {
                    Spacer()
                    if perfilVM.foto != "" {
                        if #available(iOS 15.0, *) {
                            AsyncImage(url: URL(string: perfilVM.foto)) { imagem in
                                imagem
                                    .resizable()
                                    .frame(width: 150, height: 150)
                                    .clipShape(Circle())
                                
                            } placeholder: {
                                Image("placeholder")
                                    .resizable()
                                    .frame(width: 150, height: 150)
                                    .clipShape(Circle())
                            }

                        }
                    } else {
                        Image("placeholder")
                            .resizable()
                            .frame(width: 150, height: 150, alignment: .center)
                            .clipShape(Circle())
                    }
                    Spacer()
                }
                .padding(.top,30)
                .padding(.bottom,20)
                
                Text("Nome:")
                    .font(.system(size: 20))
                    .foregroundColor(.gray)
                
                TextField("Nome", text: $perfilVM.nome)
                    .padding([.trailing,.leading  , .bottom], 10)
                
                Text("Email:")
                    .font(.system(size: 20))
                    .foregroundColor(.gray)
                
                TextField("Nome", text: $perfilVM.email)
                    .padding([.trailing,.leading], 10)
                    .padding(.bottom , 30)
                
                HStack {
                    Spacer()
                    if #available(iOS 15.0, *) {
                        Button {
                            //                        registrarVM.registrar(nome: nome, email: email, senha: senha)
                            self.mostrarOpcoes = true
                        } label: {
                            Text("Atualizar Dados")
                                .frame(width: 300, height: 30)
                                .foregroundColor(.white)
                            
                            
                        }.buttonStyle(.bordered)
                            .background(Color.blue)
                            .padding(.bottom,20)
                    }
                    Spacer()
                }
                
                
                NavigationLink(isActive: $alterarDados) {
                    AtualizarDadosView(email: perfilVM.email, nome: perfilVM.nome)
                } label: {
                    EmptyView()
                }
                
                NavigationLink(isActive: $alterarSenha) {
                    AtualizarSenhaView()
                } label: {
                    EmptyView()
                }

                
            }
            .navigationTitle("Perfil")
            .padding([.leading, .trailing], 10)
            
        }
        .alert(isPresented: $perfilVM.mostrarMensagemErro) {
            Alert(
                title: Text("OOPS"),
                message: Text(perfilVM.mensagemErro),
                dismissButton: .default(Text("OK"), action: {
                    perfilVM.mostrarMensagemErro = false
                })
            )
        }
        .actionSheet(isPresented: $mostrarOpcoes, content: {
            ActionSheet(title: Text("Opções"), message: Text("Selecione uma ação para executar"), buttons: [
                   .default(Text("Alterar dados")) {
                       self.alterarDados = true
                   },
                   .default(Text("Alterar Senha")) {
                       self.alterarSenha = true
                   },
                   .default(Text("Alterar Imagem")) {
                       self.showImagePicker = true
                       self.sourceType = .photoLibrary
                   },
                   .cancel()
               ])
        })
        .sheet(isPresented: $showImagePicker) {
            ImagePicker(image: $perfilVM.imagem, isShown: self.$showImagePicker, sourceType: self.sourceType)
            let _ = perfilVM.atualizarFoto(jwt)
            
        }
        .onAppear {
            self.perfilVM.getPerfil(jwt)
        }
    }
}

struct PerfilView_Previews: PreviewProvider {
    static var previews: some View {
        PerfilView()
    }
}
