import SwiftUI

struct RegistroView: View {
    
    @Environment(\.presentationMode) var presentationMode
    @StateObject var registroVM = RegistroVM()
    
    var body: some View {
        VStack {
            
            Text("EventosApp")
                .font(.system(size: 50))
                .padding(.bottom,16)
            
            Text("Registro")
                .font(.system(size: 30))
                .foregroundColor(.gray)
            
            if registroVM.usuarioRegistrado {
                Text("Usuário Registrado")
                    .foregroundColor(.green)
            }
            
            TextField("Digite seu nome", text: $registroVM.nome)
                .padding()
            
            TextField("Digite seu email", text: $registroVM.email)
                .autocapitalization(.none)
                .padding()
            
            SecureField("Digite sua senha", text: $registroVM.senha)
                .autocapitalization(.none)
                .padding()
            //.padding(.bottom,30)
                .autocapitalization(.none)
            
            if #available(iOS 15.0, *) {
                Button {
                    registroVM.registrar()
                } label: {
                    Text("Registrar")
                        .frame(width: 300, height: 30)
                        .foregroundColor(.white)
                    
                    
                }.buttonStyle(.bordered)
                    .background(Color.blue)
                    .padding(.bottom,20)
            }
            
            Button {
                self.presentationMode.wrappedValue.dismiss()
            } label: {
                Text("Voltar ao login")
            }
            
            
            
        }
        .padding()
        .alert(isPresented: $registroVM.mostrarMensagemErro) {
            Alert(
                title: Text("OOPS"),
                message: Text(registroVM.mensagemErro),
                dismissButton: .default(Text("OK"), action: {
                    registroVM.mostrarMensagemErro = false
                })
            )
        }
        
        .navigationBarBackButtonHidden(true)
    }
}

struct RegistroView_Previews: PreviewProvider {
    static var previews: some View {
        RegistroView()
    }
}
