import SwiftUI

struct SolicitacoesView: View {
    
    @StateObject var solicitacoesVM = SolicitacoesVM()
    @State var eventoId: Int
    @AppStorage("jwt") var jwt = ""
    
    var body: some View {
        ScrollView {
            
            Picker("Selecione um Tipo", selection: $solicitacoesVM.opcao) {
                ForEach(TiposSolicitacoes.allCases,id: \.self) {
                    Text($0.rawValue)
                }
            }
            .pickerStyle(SegmentedPickerStyle())
            .onChange(of: solicitacoesVM.opcao, perform: { newValue in
                if solicitacoesVM.opcao == .pendentes {
                    solicitacoesVM.getSolicitacoes(jwt: jwt , evento: eventoId)
                } else {
                    solicitacoesVM.consultarParticipacoes(jwt: jwt, eventoId: eventoId)
                }
            })
            .padding()
            
            if solicitacoesVM.opcao == .pendentes {
                if solicitacoesVM.solicitacoes.count != 0 {
                    ForEach(solicitacoesVM.solicitacoes, id: \.id) { solicitacao in
                        HStack {
                            VStack {
                                if #available(iOS 15.0, *) {
                                    AsyncImage(url: URL(string: solicitacao.participante.foto)) { imagem in
                                        imagem
                                            .resizable()
                                            .frame(width: 80, height: 80)
                                        
                                    } placeholder: {
                                        Image("placeholder")
                                            .resizable()
                                            .frame(width: 80, height: 80)
                                    }
                                    
                                }
                            }
                            
                            
                            VStack(alignment: .leading){
                                Text(solicitacao.participante.nome.prefix(30))
                                    .foregroundColor(.black)
                                    .font(.system(size: 22))
                                //.padding(.bottom,10)
                                
                                Text(solicitacao.participante.email.prefix(40))
                                    .foregroundColor(.gray)
                                    .font(.system(size: 18))
                                //.foregroundColor(.gray)
                            }
                            .alert(isPresented: $solicitacoesVM.solicitacaoApagada) {
                                Alert(
                                    title: Text("Sucesso"),
                                    message: Text("Solicitacao Apagada"),
                                    dismissButton: .default(Text("OK"), action: {
                                        solicitacoesVM.solicitacaoApagada = false
                                        solicitacoesVM.getSolicitacoes(jwt: jwt, evento: eventoId)
                                    })
                                )
                            }
                            
                            Spacer()
                            VStack {
                                HStack {
                                    Button {
                                        solicitacoesVM.apagarSolicitacao(jwt: jwt, solicitacaoId: solicitacao.id)
                                    } label: {
                                        Image(systemName: "trash.circle.fill")
                                            .font(.system(size: 40))
                                            .background(Color.white)
                                            .foregroundColor(.red)
                                    }
                                    
                                    
                                    Button {
                                        solicitacoesVM.confirmarSolicitacao(jwt: jwt, solicitacao: solicitacao.id)
                                    } label: {
                                        Image(systemName: "checkmark")
                                            .font(.system(size: 40))
                                            .foregroundColor(.green)
                                    }
                                }
                                
                            }
                            .padding(.leading,10)
                            .alert(isPresented: $solicitacoesVM.solicitacaoConfirmada) {
                                Alert(
                                    title: Text("Sucesso"),
                                    message: Text("Presenca confirmada"),
                                    dismissButton: .default(Text("OK"), action: {
                                        solicitacoesVM.solicitacaoConfirmada = false
                                        solicitacoesVM.getSolicitacoes(jwt: jwt, evento: eventoId)
                                    })
                                )
                            }
                        }.padding()
                        
                    }
                } else {
                    Text("Não há solicitações")
                }
            } else {
                if solicitacoesVM.participacoesConfirmadas.count != 0 {
                    ForEach(solicitacoesVM.participacoesConfirmadas, id: \.id) { participacao in
                        
                        HStack {
                            VStack {
                                if #available(iOS 15.0, *) {
                                    AsyncImage(url: URL(string: participacao.participante.foto)) { imagem in
                                        imagem
                                            .resizable()
                                            .frame(width: 80, height: 80)
                                        
                                    } placeholder: {
                                        Image("placeholder")
                                            .resizable()
                                            .frame(width: 80, height: 80)
                                    }
                                    
                                }
                            }
                            
                            
                            VStack(alignment: .leading){
                                Text(participacao.participante.nome.prefix(30))
                                    .foregroundColor(.black)
                                    .font(.system(size: 22))
                                //.padding(.bottom,10)
                                
                                Text(participacao.participante.email.prefix(40))
                                    .foregroundColor(.gray)
                                    .font(.system(size: 18))
                                //.foregroundColor(.gray)
                            }
                            .alert(isPresented: $solicitacoesVM.participacaoRemovida) {
                                Alert(
                                    title: Text("Sucesso"),
                                    message: Text("Participante removido"),
                                    dismissButton: .default(Text("OK"), action: {
                                        solicitacoesVM.participacaoRemovida = false
                                        solicitacoesVM.consultarParticipacoes(jwt: jwt, eventoId: eventoId)
                                    })
                                )
                            }
                            
                            Spacer()
                            VStack {
                                HStack {
                                    Button {
                                        solicitacoesVM.removerParticipacao(jwt: jwt, assentoId: participacao.id)
                                    } label: {
                                        Image(systemName: "trash.circle.fill")
                                            .font(.system(size: 40))
                                            .background(Color.white)
                                            .foregroundColor(.red)
                                    }
                                    
                                }
                                
                            }
                            .padding(.leading,10)
                        }.padding()
                        
                    }
                } else {
                    Text("Não há participacoes confirmadas")
                }
                
            }
            
            
            
        }
        .navigationTitle("Solicitacoes")
        .onAppear {
            solicitacoesVM.getSolicitacoes(jwt: jwt , evento: eventoId)
        }
    }
}

struct SolicitacoesView_Previews: PreviewProvider {
    static var previews: some View {
        SolicitacoesView(eventoId: 3)
    }
}
