import { Evento } from './../../entidades/Evento.entity';
import { Repository, getManager } from 'typeorm';
import { IEventoRepositorio } from './../IEventoRepositorio';

export class EventoRepositorio implements IEventoRepositorio {
    private repositorio: Repository<Evento>

    constructor() {
        this.repositorio = getManager().getRepository(Evento)
    }

    async salvar(evento: Evento): Promise<void> {
        await this.repositorio.save(evento)
    }

    async findUltimosEventos(): Promise<Evento[]> {
        const eventos = await this.repositorio.createQueryBuilder('evento').leftJoin('evento.assentos', 'assento').andWhere('evento.id = assento.evento',)
            .addSelect(['assento.id', 'assento.numeracao', 'assento.status']).orderBy('evento.id').limit(30).getMany()
        return eventos
    }

    async findById(id: number): Promise<Evento> {
        const evento = await this.repositorio.findOne(id)
        return evento
    }

    async findByCodigo(codigo: string): Promise<Evento> {
        const evento = await this.repositorio.findOne({ codigo: codigo })
        return evento
    }

    async apagar(evento: Evento): Promise<void> {
        await this.repositorio.remove(evento)
    }

    async getParticipacoes(eventoId: number): Promise<any> {
        const participacoes = await this.repositorio
            .createQueryBuilder('evento')
            .select(['evento.id', 'evento.titulo'])
            .where('evento.id = :id', { id: eventoId })
            .addSelect(['evento.titulo'])
            .leftJoinAndSelect('evento.assentos', 'assento')
            .andWhere('assento.status = :status ', { status: 'OCUPADO' })
            .leftJoin('assento.participante', 'participante')
            .addSelect(['participante.id', 'participante.nome', 'participante.email', 'participante.foto'])
            .getMany()
        return participacoes
    }

}