import { Solicitacao } from './../../entidades/Solicitacao.entity';
import { Repository, getManager } from 'typeorm';
import { ISolicitacaoRepositorio } from './../ISolicitacaoRepositorio';


export class SolicitacaoRepositorio implements ISolicitacaoRepositorio {
    private repositorio: Repository<Solicitacao>

    constructor() {
        this.repositorio = getManager().getRepository(Solicitacao)
    }

    async salvar(solicitacao: Solicitacao): Promise<void> {
        await this.repositorio.save(solicitacao)
    }

    async findById(id: number): Promise<Solicitacao> {
        return await this.repositorio.findOne(id)
    }

    async delete(solicitacao: Solicitacao): Promise<void> {
        await this.repositorio.delete(solicitacao)
    }

    async getSolicitacoes(eventoId: number): Promise<any> {
        const solicitacoes = await this.repositorio
            .createQueryBuilder('solicitacao')
            .leftJoin('solicitacao.evento', 'evento')
            .andWhere('evento.id = :id', { id: eventoId })
            .leftJoin('solicitacao.participante', 'participante')
            .addSelect(['participante.nome', 'participante.email', 'participante.foto'])
            .getMany()
        //console.log(solicitacoes)
        return solicitacoes
    }

    async apagar(solicitacao: Solicitacao): Promise<void> {
        await this.repositorio.remove(solicitacao)
    }
}