import { Assento } from './../../entidades/Assento.entity';
import { EntityManager, getManager, Repository } from 'typeorm';
import { Evento } from '../../entidades/Evento.entity';
import { Usuario } from '../../entidades/Usuario.entity';
import { UpdateUsuarioDTO } from '../dto/updateUsuarioDTO';
import { IUsuarioRepositorio } from './../IUsuarioRepositorio';
export class UsuarioRepositorio implements IUsuarioRepositorio {

    private repositorio: Repository<Usuario>

    constructor() {
        this.repositorio = getManager().getRepository(Usuario)
    }

    async getMeusEventos(id: number): Promise<any> {
        const eventos = await this.repositorio
            .createQueryBuilder("usuario")
            .where('usuario.id = :id', { id: id })
            .leftJoinAndSelect("usuario.eventos", "evento")
            .addSelect(['evento.id', 'evento.titulo', 'evento.descricao', 'evento.data', 'evento.imagem'])
            .leftJoin('evento.assentos', 'assento')
            .addSelect(['assento.id', 'assento.numeracao', 'assento.status'])
            .getMany();
        return eventos
    }

    async consultarParticipacoes(usuarioId: number): Promise<any> {
        const eventos = await this.repositorio
            .createQueryBuilder('usuario')
            .where('usuario.id = :id', { id: usuarioId })
            .leftJoin('usuario.participacoes', 'participacoes')
            .where('participacoes.participante = :usuario', { usuario: usuarioId })
            .leftJoin('participacoes.evento', 'eventos')
            .addSelect(['participacoes.numeracao'])
            .addSelect(['eventos.id', 'eventos.titulo', 'eventos.descricao', 'eventos.data', 'eventos.imagem', 'eventos.total_assentos_linha', 'eventos.total_assentos_coluna','eventos.codigo', 'eventos.link'])
            .leftJoin('eventos.assentos', 'assento')
            .addSelect(['assento.id', 'assento.numeracao', 'assento.status'])
            .getMany()

        return eventos

    }

    async findById(id: number): Promise<Usuario> {
        const usuario = await this.repositorio.findOne(id)
        return usuario
    }

    async findByEmail(email: string): Promise<Usuario> {
        const usuario = await this.repositorio.findOne({ email: email })
        return usuario
    }

    async salvar(usuario: Usuario): Promise<void> {
        await this.repositorio.save(usuario)
    }

    async updateInformacoes(novasInformacoes: UpdateUsuarioDTO, usuario: number): Promise<void> {
        const perfil = await this.repositorio.findOne({ id: usuario })
        perfil.nome = novasInformacoes.nome
        perfil.email = novasInformacoes.email
        await this.repositorio.save(perfil)
    }

    async updateFotoPerfil(imagemUsuario: string, usuario: number): Promise<void> {
        const perfil = await this.repositorio.findOne({ id: usuario })
        perfil.foto = imagemUsuario
        await this.repositorio.save(perfil)
    }

    async updateSenha(novaSenha: string, usuario: number): Promise<void> {
        const perfil = await this.repositorio.findOne({ id: usuario })
        perfil.senha = novaSenha
        await this.repositorio.save(perfil)
    }



}