import { AdicionarEventoDTO } from './adicionarEventoDTO';
import { AdicionarEventoUseCase } from './adicionarEventoUseCase';
import { Usuario } from './../../entidades/Usuario.entity';
import { Request, Response } from 'express';


import multer from 'multer';
import { extname } from 'path';

export class AdicionarEventoController {

    constructor(private adicionarEventoUseCase: AdicionarEventoUseCase) { }


    async handle(request: Request, response: Response): Promise<Response> {

        const storage = multer.diskStorage({
            destination: './uploads',
            filename(_, file, callback) {
                const randomName = Math.random().toString(20).substr(2, 12)
                return callback(null, `${randomName}${extname(file.originalname)}`)
            },
        })

        const upload = multer({ storage, limits: { fieldSize: 40 * 1024 * 1024 } }).single('imagem')
        const usuario = request['usuario'] as Usuario
        try {

            await upload(request, response, async erro => {

                if (erro)
                    throw new Error('Erro ao salvar imagem, tente novamente')
                else {
                    const data: AdicionarEventoDTO = request.body
                    console.log(request.body)
                    const linkImagem = `http://localhost:8000/api/uploads/${request.file.filename}`
                    await this.adicionarEventoUseCase.execute(data, linkImagem, usuario.id)
                    return response.status(201).json({ mensagem: 'Evento adicionado' })
                }

            })

        } catch (erro) {
            return response.status(500).json({
                mensagem: erro.message || 'Erro inesperado'
            })
        }
    }

}