import { IAssentoRepositorio } from './../../repositorios/IAssentoRepositorio';
import { Assento } from './../../entidades/Assento.entity';
import { Evento } from './../../entidades/Evento.entity';
import { IUsuarioRepositorio } from './../../repositorios/IUsuarioRepositorio';
import { AdicionarEventoDTO } from './adicionarEventoDTO';
import { IEventoRepositorio } from './../../repositorios/IEventoRepositorio';
import * as crypto from 'crypto'
export class AdicionarEventoUseCase {
    constructor(private eventoRepositorio: IEventoRepositorio, private usuarioRepositorio: IUsuarioRepositorio, private assentoRepositorio: IAssentoRepositorio) { }

    async execute(data: AdicionarEventoDTO, imagem: string, usuarioId: number) {

        const usuario = await this.usuarioRepositorio.findById(usuarioId)


        if (!usuario)
            throw new Error('Não autorizado')

        const evento = new Evento()

        evento.titulo = data.titulo
        evento.descricao = data.descricao
        evento.data = data.data
        evento.link = data.link
        evento.imagem = imagem
        evento.codigo = crypto.randomBytes(4).toString('hex');
        evento.criador = usuario
        evento.total_assentos_coluna = data.total_assentos_coluna
        evento.total_assentos_linha = data.total_assentos_linha

        await this.eventoRepositorio.salvar(evento)

        const total = data.total_assentos_coluna * data.total_assentos_linha
        for (let i = 0; i < total; i++) {
            const assento = new Assento()
            if (data.assentos_bloqueados.includes(i.toString())) {
                assento.status = "BLOQUEADO"
            } else {
                assento.status = "LIVRE"
            }
            assento.evento = evento
            assento.numeracao = i
            await this.assentoRepositorio.salvar(assento)
        }
    }
}