import { Usuario } from './../../entidades/Usuario.entity';
import { AdicionarUsuarioDTO } from './adicionarUsuarioDTO';
import { IUsuarioRepositorio } from './../../repositorios/IUsuarioRepositorio';
import bcryptjs from "bcryptjs"

export class AdicionarUsuarioUseCase {
    constructor(private usuarioRepositorio: IUsuarioRepositorio) {}

    async execute(data: AdicionarUsuarioDTO) {
        const usuarioExiste = await this.usuarioRepositorio.findByEmail(data.email)
        if (usuarioExiste) {
            throw new Error('Usuario já existe')
        }

        const usuario = new Usuario()
        usuario.email = data.email
        usuario.nome = data.nome
        usuario.eventos = []
        usuario.solicitacoes = []
        usuario.participacoes = []
        usuario.senha = await bcryptjs.hash(data.senha, 10)
        
        await this.usuarioRepositorio.salvar(usuario)
    }
}