import { AdicionarUsuarioDTO } from './adicionarUsuarioDTO';
import { Request, Response } from 'express';
import { AdicionarUsuarioUseCase } from './AdicionarUsuarioUseCase';

export class AdicionarUsuarioController {

    constructor(private adicionarUsuarioUseCase: AdicionarUsuarioUseCase) { }

    async handle(request: Request, response: Response): Promise<Response> {

        const { nome, email, senha }: AdicionarUsuarioDTO = request.body

        if (!nome || !email || !senha) {
            return response.status(400).json({ mensagem: 'Parâmetros inválidos' })
        }

        try {
            await this.adicionarUsuarioUseCase.execute({
                nome,
                email,
                senha
            })

            return response.status(201).json({ mensagem: 'Usuário registrado' })
        } catch (erro) {
            if (!erro.messagem) {
                return response.status(401).json({
                    mensagem: 'Email já registrado'
                })
            }
            return response.status(500).json({
                mensagem: 'Erro inesperado'
            })
        }

    }

}