import { Request, Response } from 'express';
import { Usuario } from './../../entidades/Usuario.entity';
import { ApagarEventoUseCase } from "./apagarEventoUseCase"

export class ApagarEventoController {

    constructor(private apagarEventoUseCase: ApagarEventoUseCase) { }

    async handle(request: Request, response: Response): Promise<Response> {
        const usuario = request['usuario'] as Usuario

        if (!usuario) {
            return response.status(400).json({ mensagem: 'Não autorizado' })
        }

        try {
            const eventoId = Number(request.params['id'])
            await this.apagarEventoUseCase.execute(usuario.id,eventoId)
            return response.status(200).json({ mensagem: 'Evento apagado com sucesso' })

        } catch (erro) {
            return response.status(500).json({
                mensagem: erro.message || 'Erro inesperado'
            })
        }
    }

}