import { Usuario } from './../../entidades/Usuario.entity';
import { Request, Response } from 'express';
import { AtualizarFotoPerfilUseCase } from './atualizarFotoPerfilUseCase';

import multer from 'multer';
import { extname } from 'path';

export class AtualizarFotoPerfilController {

    constructor(private atualizarFotoPerfilUseCase: AtualizarFotoPerfilUseCase) { }


    async handle(request: Request, response: Response): Promise<Response> {

        const storage = multer.diskStorage({
            destination: './uploads',
            filename(_, file, callback) {
                const randomName = Math.random().toString(20).substr(2, 12)
                return callback(null, `${randomName}${extname(file.originalname)}`)
            },
        })
        const upload = multer({ storage, limits: { fieldSize: 40 * 1024 * 1024 } }).single('imagem')


        const { imagem } = request.body
        const usuario = request['usuario'] as Usuario
        try {

            await upload(request, response, async erro => {
                if (erro)
                    throw new Error('Erro ao salvar imagem, tente novamente')
                else {
                    const linkImagem = `http://localhost:8000/api/uploads/${request.file.filename}`
                    await this.atualizarFotoPerfilUseCase.execute(usuario.id, linkImagem)
                    return response.status(201).json({ mensagem: 'Imagem atualizada' })
                }

            })

        } catch (erro) {
            return response.status(500).json({
                mensagem: erro.message || 'Erro inesperado'
            })
        }
    }

}