import { Usuario } from './../../entidades/Usuario.entity';
import { Request, Response } from 'express';
import { ConfirmarSolicitacaoUseCase } from './confirmarSolicitacaoUseCase';


export class ConfirmarSolicitacaoController {

    constructor(private confirmarSolicitacaoUseCase: ConfirmarSolicitacaoUseCase) { }

    async handle(request: Request, response: Response): Promise<Response> {
        const solicitacaoId = Number(request.params['id'])

        if (!solicitacaoId) {
            return response.status(400).json({ mensagem: 'Parâmetros inválidos' })
        }

        const usuario = request['usuario'] as Usuario

        if (!usuario) {
            return response.status(403).json({ mensagem: 'Não autorizado' })
        }

        try {
            const assento = await this.confirmarSolicitacaoUseCase.execute(solicitacaoId)
            if (!assento)
                return response.status(201).json({ mensagem: 'Não há mais assentos' })
            return response.status(200).json({ mensagem: 'Solicitacao confirmada' })
        } catch (erro) {
            return response.status(500).json({
                mensagem: erro.message || 'Erro inesperado'
            })
        }
    }

}