import { Assento } from './../../entidades/Assento.entity';
import { EventoRepositorio } from './../../repositorios/implementacao/EventoRepositorio';
import { IAssentoRepositorio } from './../../repositorios/IAssentoRepositorio';
import { IUsuarioRepositorio } from './../../repositorios/IUsuarioRepositorio';
import { IEventoRepositorio } from './../../repositorios/IEventoRepositorio';
import { ISolicitacaoRepositorio } from './../../repositorios/ISolicitacaoRepositorio';

export class ConfirmarSolicitacaoUseCase {

    constructor(private solicitacaoRepositorio: ISolicitacaoRepositorio, private assentoRepositorio: IAssentoRepositorio, private eventoRepositorio: EventoRepositorio) { }

    async execute(solicitacaoId: number): Promise<Assento> {

        const solicitacao = await this.solicitacaoRepositorio.findById(solicitacaoId)

        if (!solicitacao)
            throw new Error('Solicitacao não existe')

        const usuario = solicitacao.participante
        const evento = solicitacao.evento


        const assento = evento.assentos.find(assento => assento.status == 'LIVRE')

        if (assento) {
            assento.participante = usuario
            assento.status = "OCUPADO"
            await this.assentoRepositorio.salvar(assento)
            await this.solicitacaoRepositorio.delete(solicitacao)
        }


        return assento

    }

}