import { ConsultarEventoUseCase } from './consultarEventoUseCase';
import { Usuario } from './../../entidades/Usuario.entity';
import { Request, Response } from 'express';


export class ConsultarEventoController {

    constructor(private consultarEventoUseCase: ConsultarEventoUseCase) { }

    async handle(request: Request, response: Response): Promise<Response> {
        const usuario = request['usuario'] as Usuario

        if (!usuario) {
            return response.status(400).json({ mensagem: 'Não autorizado' })
        }

        try {
            const codigo = request.params['codigo']
            const evento = await this.consultarEventoUseCase.execute(codigo)
            if ( evento === null || evento === undefined)
                return response.status(201).json({mensagem: 'evento não existe'})
            
            const permissaoAlterar = (  evento.criador.id === usuario.id   )

            return response.status(200).json({ ...evento , permissaoAlterar })

        } catch (erro) {
            return response.status(500).json({
                mensagem: erro.message || 'Erro inesperado'
            })
        }
    }

}