import { Request, Response } from 'express';
import { Usuario } from './../../entidades/Usuario.entity';
import { ConsultarEventosCriadosUseCase } from './consultarEventosCriadosUseCase';
export class ConsultarEventosCriadosController {

    constructor(private consultarEventosCriadosUseCase: ConsultarEventosCriadosUseCase) { }

    async handle(request: Request, response: Response): Promise<Response> {
        const usuario = request['usuario'] as Usuario

        if (!usuario) {
            return response.status(400).json({ mensagem: 'Não autorizado' })
        }

        try {
            const responseUsuario = await this.consultarEventosCriadosUseCase.execute(usuario.id)
            const eventos = responseUsuario.map(response => response['eventos'])[0]
            if (eventos.length == 0) {
                return response.status(201).json({ mensagem: "Não há eventos" })
            }
            return response.status(200).json(eventos)

        } catch (erro) {
            return response.status(500).json({
                mensagem: erro.message || 'Erro inesperado'
            })
        }
    }

}