import { Usuario } from './../../entidades/Usuario.entity';
import { Request, Response } from 'express';
import { ConsultarParticipacoesUseCase } from './consultarParticipacoesUseCase';

export class ConsultarParticipacoesController {

    constructor(private consultarParticipacoesUseCase: ConsultarParticipacoesUseCase) { }

    async handle(request: Request, response: Response): Promise<Response> {
        const usuario = request['usuario'] as Usuario

        if (!usuario) {
            return response.status(400).json({ mensagem: 'Não autorizado' })
        }

        try {
            const eventos = await this.consultarParticipacoesUseCase.execute(usuario.id)
            if (eventos === null || eventos === undefined || eventos.length == 0)
                return response.status(201).json({ mensagem: 'Não há participacao' })

            return response.status(200).json(eventos[0].participacoes.map(evento => evento['evento']))

        } catch (erro) {
            return response.status(500).json({
                mensagem: erro.message || 'Erro inesperado'
            })
        }
    }

}