import { Request, Response } from 'express';
import { Usuario } from './../../entidades/Usuario.entity';
import { ConsultarParticipacoesEventoUseCase } from "./consultarParticipacoesEventoUseCase"

export class ConsultarParticipacoesEventoController {

    constructor(private consultarParticipacoesUseCase: ConsultarParticipacoesEventoUseCase) { }

    async handle(request: Request, response: Response): Promise<Response> {
        const usuario = request['usuario'] as Usuario
        const eventoId = Number(request.params['id'])

        if (!usuario) {
            return response.status(400).json({ mensagem: 'Não autorizado' })
        }

        try {
            const codigo = request.params['codigo']
            const participacoes = await this.consultarParticipacoesUseCase.execute(eventoId)
            if ( participacoes === null || participacoes === undefined || participacoes.length == 0)
                return response.status(201).json({mensagem: 'Não há participacoes confirmadas'})
    
            return response.status(200).json(participacoes)

        } catch (erro) {
            return response.status(500).json({
                mensagem: erro.message || 'Erro inesperado'
            })
        }
    }

}