import { Usuario } from './../../entidades/Usuario.entity';
import { Request, Response } from 'express';
import { ConsultarSolicitacoesUseCase } from './consultarSolicitacoesUseCase';
export class ConsultarSolicitacoesController {

    constructor(private consultarSolicitacoesUseCase: ConsultarSolicitacoesUseCase) { }

    async handle(request: Request, response: Response): Promise<Response> {
        const usuario = request['usuario'] as Usuario
        const eventoId = Number(request.params['id'])

        if (!usuario) {
            return response.status(400).json({ mensagem: 'Não autorizado' })
        }

        try {
            const solicitacoes = await this.consultarSolicitacoesUseCase.execute(eventoId)
            if (solicitacoes === null || solicitacoes.length == 0)
                return response.status(201).json({mensagem: 'Nenhuma Solicitacao Encontrada'})
            return response.status(200).json(solicitacoes)

        } catch (erro) {
            return response.status(500).json({
                mensagem: erro.message || 'Erro inesperado'
            })
        }
    }

}