import { LogarUsuarioDTO } from './logarUsuarioDTO';
import { Request, Response } from 'express';
import { LogarUsuarioUseCase } from './logarUsuarioUseCase';
import { sign } from 'jsonwebtoken'

export class LogarUsuarioController {

    constructor(private logarUsuarioUseCase: LogarUsuarioUseCase) {}

    async handle(request: Request, response: Response): Promise<Response> {
        const { email , senha } : LogarUsuarioDTO = request.body

        if ( !email || !senha) {
            return response.status(400).json({messagem: 'Parametros inválidos'})
        }

        try {
            const usuario = await this.logarUsuarioUseCase.execute(email, senha)
            if (!usuario)
                return response.status(400).json({mensagem: 'Não autorizado'})

            const payload = {
                id: usuario.id
            }
            
            const token = sign(payload, process.env.SECRET_KEY)

            return response.status(200).json({
                mensagem: 'Login sucesso',
                jwt: token
            })
            
        } catch (erro) {
            return response.status(500).json({
                mensagem: erro.message || 'Erro inesperado'
            })
        }
    }

}