import { Usuario } from './../../entidades/Usuario.entity';
import { Request, Response } from 'express';
import { SolicitarParticipacaoUseCase } from './solicitarParticipacaoUseCase';
export class SolicitarParticipacaoController {

    constructor(private solicitarParticipacaoUseCase: SolicitarParticipacaoUseCase) { }

    async handle(request: Request, response: Response): Promise<Response> {
        const eventoId = Number(request.params['id'])

        if (!eventoId) {
            return response.status(400).json({ mensagem: 'Parâmetros inválidos' })
        }
        
        const usuario = request['usuario'] as Usuario

        if (!usuario) {
            return response.status(403).json({ mensagem: 'Não autorizado' })
        }

        try {
            await this.solicitarParticipacaoUseCase.execute(usuario.id,eventoId)

            return response.status(201).json({ mensagem: 'Solicitacao enviada' })
        } catch (erro) {
            return response.status(500).json({
                mensagem: erro.message || 'Erro inesperado'
            })
        }
    }

}